@@ -530,7 +530,6 @@ def version_compare(
                 return True
         # Sorry about this but ubuntu versioning scheme is a PITA
         if "ubuntu" in compare_ver or "build" in compare_ver or "deb" in compare_ver:
-            compare_with_build_tag = False
             # Trim any epoch
             if ":" in compare_ver:
                 compare_ver = compare_ver.split(":")[-1]
@@ -546,7 +545,6 @@ def version_compare(
                 tmpcvArr = compare_ver.split("deb")
             else:
                 tmpcvArr = compare_ver.split("build")
-                compare_with_build_tag = True
             ubuntu_mode_detected = True
             tmpmv = None
             if max_version and (
